import 'package:flutter/material.dart';
import 'package:latlong2/latlong.dart';
import 'dart:convert';

// MarkerData holds data for the dynamically allocated markers
class MarkerData {
  final LatLng location;
  final double size;
  final Color color;
  final double radius;

  MarkerData({required this.location, required this.size, required this.color, required this.radius});
}

// parseMarkerData parses jsonData into an object of type MakerData
List<MarkerData> parseMarkerData(String jsonString) {
  final parsed = json.decode(jsonString);
  return List<MarkerData>.from(parsed.map((data) => MarkerData(
    location: LatLng(data['latitude'], data['longitude']),
    size: data['size'].toDouble(),
    color: parseColor(data['color']),
    radius: data['radius'].toDouble(),
  )));
}

// parseColor parses the color strings into Colors types
Color parseColor(String colorString) {
  switch (colorString) {
    case 'blue':
      return Colors.blue;
    case 'red':
      return Colors.red;
    case 'green':
      return Colors.green;
    default:
      return Colors.black; // Default color if unrecognized
  }
}